import React, { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';

import './styles.css';

RecycledList.propTypes = process.env.NODE_ENV !== "production" ? {
  attrList: PropTypes.array.isRequired,
  itemFn: PropTypes.func.isRequired,
  itemHeight: PropTypes.number,
  className: PropTypes.string,
  rowOffset: PropTypes.number
} : {};

RecycledList.defaultProps = {
  attrList: [],
  itemHeight: 50,
  className: 'DefaultContainer',
  rowOffset: 6
};

export default function RecycledList(_ref) {
  var attrList = _ref.attrList,
      itemHeight = _ref.itemHeight,
      itemFn = _ref.itemFn,
      className = _ref.className,
      rowOffset = _ref.rowOffset;

  var _useState = useState(0),
      scrollTop = _useState[0],
      setScrollTop = _useState[1];

  var _useState2 = useState(0),
      viewableHeight = _useState2[0],
      setViewableHeight = _useState2[1];

  var wrapper = useRef(null);
  var setScroll = function setScroll(e) {
    return setScrollTop(e.target.scrollTop);
  };

  useEffect(function () {
    if (wrapper.current) {
      setViewableHeight(parseFloat(window.getComputedStyle(wrapper.current).height));
    }
  }, []);

  var itemStyle = function itemStyle(index) {
    return {
      height: itemHeight,
      top: itemHeight * index
    };
  };
  var listStyle = function listStyle() {
    return {
      height: attrList.length * itemHeight,
      position: 'relative'
    };
  };

  var inView = function inView(position) {
    return position < viewableHeight + scrollTop + (rowOffset - 1) * itemHeight && position > scrollTop - rowOffset * itemHeight;
  };

  return React.createElement(
    'div',
    { className: className },
    React.createElement(
      'div',
      { className: 'Wrapper', ref: wrapper, onScroll: setScroll },
      React.createElement(
        'div',
        { style: listStyle() },
        attrList.map(function (attrs, index) {
          return inView(index * itemHeight) && React.createElement(
            'div',
            { className: 'ItemWrapper', key: index, style: itemStyle(index, itemHeight) },
            itemFn(attrs)
          );
        })
      )
    )
  );
}